==> ejc-procurement-impl-3.0.0-20251205.035710-71-sources.jar: com/ejianc/business/procurement/plan/bean/AnswerEntity.java <==
package com.ejianc.business.procurement.plan.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.procurement.plan.bean.AnswerDetailEntity;
/**
 * 计划答疑清单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procurement_purchase_answer")
public class AnswerEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="make_date")
    private Date makeDate; // 编制日期
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_name")
    private String orgName; // 项目部名称
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 项目部上级名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级编码
    @TableField(value="all_org_name")
    private String allOrgName; // 所属组织(所属单位-项目经理部)
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="business_type")
    private String businessType; // 业务类别1-工程，2-货物，3-服务
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="purchase_org_name")
    private String purchaseOrgName; // 采购单位name
    @TableField(value="informer_name")
    private String informerName; // 通知人名称
    @TableField(value="answer_type")
    private String answerType; // 答疑数据 -1 , 回复数据-2
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="project_id")
    private Long projectId; // 项目Id
    @TableField(value="org_id")
    private Long orgId; // 项目部Id
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目部上级Id
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="purchase_org_id")
    private Long purchaseOrgId; // 采购单位id
    @TableField(value="informer_id")
    private Long informerId; // 通知人id
    @TableField(value="purchase_plan_name")
    private String purchasePlanName; // 采购计划name
    @TableField(value="purchase_plan_id")
    private Long purchasePlanId; // 采购计划id
    @TableField(value="purchase_plan_code")
    private String purchasePlanCode; // 采购计划code

    
    @TableField(exist=false)
    @SubEntity(serviceName = "answerDetailService", pidName = "answerId")
    private List<AnswerDetailEntity> answerDetailList = new ArrayList<>(); // 计划答疑清单-子表

    public String getPurchasePlanName() {
        return purchasePlanName;
    }

    public void setPurchasePlanName(String purchasePlanName) {
        this.purchasePlanName = purchasePlanName;
    }

    public Long getPurchasePlanId() {
        return purchasePlanId;
    }

    public void setPurchasePlanId(Long purchasePlanId) {
        this.purchasePlanId = purchasePlanId;
    }

    public String getPurchasePlanCode() {
        return purchasePlanCode;
    }

    public void setPurchasePlanCode(String purchasePlanCode) {
        this.purchasePlanCode = purchasePlanCode;
    }

    public Date getMakeDate() {
        return makeDate;
    }

    public void setMakeDate(Date makeDate) {
        this.makeDate = makeDate;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getAllOrgName() {
        return allOrgName;
    }

    public void setAllOrgName(String allOrgName) {
        this.allOrgName = allOrgName;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getBusinessType() {
        return businessType;
    }

    public void setBusinessType(String businessType) {
        this.businessType = businessType;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getPurchaseOrgName() {
        return purchaseOrgName;
    }

    public void setPurchaseOrgName(String purchaseOrgName) {
        this.purchaseOrgName = purchaseOrgName;
    }
    public String getInformerName() {
        return informerName;
    }

    public void setInformerName(String informerName) {
        this.informerName = informerName;
    }
    public String getAnswerType() {
        return answerType;
    }

    public void setAnswerType(String answerType) {
        this.answerType = answerType;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public Long getPurchaseOrgId() {
        return purchaseOrgId;
    }

    public void setPurchaseOrgId(Long purchaseOrgId) {
        this.purchaseOrgId = purchaseOrgId;
    }
    public Long getInformerId() {
        return informerId;
    }

    public void setInformerId(Long informerId) {
        this.informerId = informerId;
    }
    
    public List<AnswerDetailEntity> getAnswerDetailList() {
        return answerDetailList;
    }

    public void setAnswerDetailList(List<AnswerDetailEntity> answerDetailList) {
        this.answerDetailList = answerDetailList;
    }
}

==> ejc-procurement-impl-3.0.0-20251212.023507-101-sources.jar: com/ejianc/business/procurement/plan/bean/AnswerEntity.java <==
package com.ejianc.business.procurement.plan.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.procurement.plan.bean.AnswerDetailEntity;
/**
 * 计划答疑清单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procurement_purchase_answer")
public class AnswerEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="make_date")
    private Date makeDate; // 编制日期
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_name")
    private String orgName; // 项目部名称
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 项目部上级名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级编码
    @TableField(value="all_org_name")
    private String allOrgName; // 所属组织(所属单位-项目经理部)
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="business_type")
    private String businessType; // 业务类别1-工程，2-货物，3-服务
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="purchase_org_name")
    private String purchaseOrgName; // 采购单位name
    @TableField(value="informer_name")
    private String informerName; // 通知人名称
    @TableField(value="answer_type")
    private String answerType; // 答疑数据 -1 , 回复数据-2
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="project_id")
    private Long projectId; // 项目Id
    @TableField(value="org_id")
    private Long orgId; // 项目部Id
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目部上级Id
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="purchase_org_id")
    private Long purchaseOrgId; // 采购单位id
    @TableField(value="informer_id")
    private Long informerId; // 通知人id
    @TableField(value="purchase_plan_name")
    private String purchasePlanName; // 采购计划name
    @TableField(value="purchase_plan_id")
    private Long purchasePlanId; // 采购计划id
    @TableField(value="purchase_plan_code")
    private String purchasePlanCode; // 采购计划code
    @TableField(value="reply_status")
    private Integer replyStatus; // 回复状态 1-待回复,2-已回复

    
    @TableField(exist=false)
    @SubEntity(serviceName = "answerDetailService", pidName = "answerId")
    private List<AnswerDetailEntity> answerDetailList = new ArrayList<>(); // 计划答疑清单-子表

    public Integer getReplyStatus() {
        return replyStatus;
    }

    public void setReplyStatus(Integer replyStatus) {
        this.replyStatus = replyStatus;
    }

    public String getPurchasePlanName() {
        return purchasePlanName;
    }

    public void setPurchasePlanName(String purchasePlanName) {
        this.purchasePlanName = purchasePlanName;
    }

    public Long getPurchasePlanId() {
        return purchasePlanId;
    }

    public void setPurchasePlanId(Long purchasePlanId) {
        this.purchasePlanId = purchasePlanId;
    }

    public String getPurchasePlanCode() {
        return purchasePlanCode;
    }

    public void setPurchasePlanCode(String purchasePlanCode) {
        this.purchasePlanCode = purchasePlanCode;
    }

    public Date getMakeDate() {
        return makeDate;
    }

    public void setMakeDate(Date makeDate) {
        this.makeDate = makeDate;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getAllOrgName() {
        return allOrgName;
    }

    public void setAllOrgName(String allOrgName) {
        this.allOrgName = allOrgName;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getBusinessType() {
        return businessType;
    }

    public void setBusinessType(String businessType) {
        this.businessType = businessType;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getPurchaseOrgName() {
        return purchaseOrgName;
    }

    public void setPurchaseOrgName(String purchaseOrgName) {
        this.purchaseOrgName = purchaseOrgName;
    }
    public String getInformerName() {
        return informerName;
    }

    public void setInformerName(String informerName) {
        this.informerName = informerName;
    }
    public String getAnswerType() {
        return answerType;
    }

    public void setAnswerType(String answerType) {
        this.answerType = answerType;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public Long getPurchaseOrgId() {
        return purchaseOrgId;
    }

    public void setPurchaseOrgId(Long purchaseOrgId) {
        this.purchaseOrgId = purchaseOrgId;
    }
    public Long getInformerId() {
        return informerId;
    }

    public void setInformerId(Long informerId) {
        this.informerId = informerId;
    }
    
    public List<AnswerDetailEntity> getAnswerDetailList() {
        return answerDetailList;
    }

    public void setAnswerDetailList(List<AnswerDetailEntity> answerDetailList) {
        this.answerDetailList = answerDetailList;
    }
}
